Using Sorcha Add-Ons
============================

In order to use thesw community utilities, first install this package in your
virtual environment along with ``Sorcha``. Once the ``Sorcha-addons`` package installed, ``Sorcha`` will automatically detect 
the available plugins and make them available during runtime. `

To use one of the plugins from the community utilities, simply add the unique
name of the plugin to the `configuration file <https://sorcha.readthedocs.io/en/latest/configfiles.html>`_ provided to ``Sorcha``, and provide the complex parameters file on the command line. For more information about running Sorcha, see the documentation available  `here <https://sorcha.readthedocs.io>`_.

